==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/plugins/General/hal/translations/hal_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/General/hal/translations/hal_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation>Plugin HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation>Sobre o plugin HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Plugin Qmmp HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Este plugin permite a detecção de dispositivos removíveis através do serviço HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Baseado no Solid (biblioteca do KDE)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Adicionar CD %1</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Adicionar volume %1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>Preferências do plugin HAL</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Detecção de áudio de CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Adicionar faixas à lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Remover faixas da lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Detecção de dispositivos removíveis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Adicionar arquivos à lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Remover arquivos da lista de reprodução</translation>
    </message>
</context>
</TS>
